OuterfacesEctoApi.QueryEngine.QuerySerializer (Outerfaces Ecto API v0.2.8)

Summary

Functions

This module provides a macro to be used in API models to serialize the model's fields.

Functions

__using__(opts)

(macro)

This module provides a macro to be used in API models to serialize the model's fields.