OuterfacesEctoApi.QueryEngine.QueryExpressor (Outerfaces Ecto API v0.2.4)
View SourceSummary
Functions
Builds a dynamic expression for filtering an associated field, supporting multiple levels of joins.
Functions
Builds a dynamic expression for filtering an associated field, supporting multiple levels of joins.
arity: 1 for[assoc], 2 for[_a, assoc], etc.operator::==,:!=,:>,:<,:>=,:<=,:is_nil,:not_nil, :in, :not_in.field: Atom for the field to filter on.value: The compare value, or nil if ignoring foris_nilchecks.