OuterfacesEctoApi.QueryEngine.QuerySerializer (Outerfaces Ecto API v0.2.8)
View SourceSummary
Functions
This module provides a macro to be used in API models to serialize the model's fields.
This module provides a macro to be used in API models to serialize the model's fields.